"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var session_service_1 = require("./session.service");
var web_storage_1 = require("@ng2plus/web-storage");
var webLocalStorageConfig = {
    prefix: 'Modulab',
    provider: 'localStorage'
};
var compressor = pako;
var PreferencesService = (function () {
    function PreferencesService(webStorageService, sessionService) {
        this.webStorageService = webStorageService;
        this.sessionService = sessionService;
        this.excluseMachinePreferences = ['localsamplecollectioncenterid'];
        this.webStorageService.setup(webLocalStorageConfig);
        this.convertPreferencesToAngular2();
    }
    PreferencesService.prototype.putPreference = function (key, value) {
        var inMemoryPreferences;
        if (this.sessionService.getPreference('isPreferencesInMemory') || false) {
            inMemoryPreferences = this.sessionService.getPreference('inMemoryPreferences');
            if (inMemoryPreferences !== null) {
                this.sessionService.putPreference(key, value);
            }
        }
        this.webStorageService
            .setup(webLocalStorageConfig)
            .set(key, value);
    };
    PreferencesService.prototype.getPreference = function (key) {
        var inMemoryPreferences;
        if (this.sessionService.getPreference('isPreferencesInMemory') || false) {
            inMemoryPreferences = this.sessionService.getPreference('inMemoryPreferences');
            if (inMemoryPreferences !== null) {
                var result = inMemoryPreferences[key];
                if (result !== null && result !== undefined) {
                    return result;
                }
            }
        }
        return this.webStorageService
            .setup(webLocalStorageConfig)
            .get(key);
    };
    PreferencesService.prototype.removePreference = function (key) {
        var inMemoryPreferences;
        if (this.sessionService.getPreference('isPreferencesInMemory') || false) {
            inMemoryPreferences = this.sessionService.getPreference('inMemoryPreferences');
            if (inMemoryPreferences !== null) {
                this.sessionService.removePreference(key);
            }
        }
        this.webStorageService
            .setup(webLocalStorageConfig)
            .remove(key);
    };
    PreferencesService.prototype.removePreferenceStartWith = function (startWith) {
        var keys = this.webStorageService.keys();
        keys.forEach(function (currentKey) {
            if (currentKey.indexOf(startWith) > -1 && typeof this.webStorageService.get(currentKey) !== 'function') {
                this.removePreference(currentKey);
            }
        }, this);
    };
    PreferencesService.prototype.getPreferencesFromMemory = function () {
        var inMemoryPreferences, binaryString, passToServer = {};
        if (this.sessionService.getPreference('isPreferencesInMemory') || false) {
            inMemoryPreferences = this.sessionService.getPreference('inMemoryPreferences');
            if (inMemoryPreferences !== null) {
                for (var key in inMemoryPreferences) {
                    if (this.preferenceMustBeLoadedInMemory(key)) {
                        passToServer[key] = inMemoryPreferences[key];
                    }
                }
                binaryString = compressor.deflate(JSON.stringify(passToServer), { to: 'string' });
                return btoa(binaryString);
            }
        }
        return null;
    };
    PreferencesService.prototype.setupPreferences = function (loginData) {
        var preferencesData = {}, isPreferencesInMemory;
        isPreferencesInMemory = loginData.preferencesInDB || false;
        this.sessionService.putPreference('inMemoryPreferences', preferencesData);
        this.sessionService.putPreference('isPreferencesInMemory', isPreferencesInMemory);
        if (isPreferencesInMemory) {
            try {
                var result = compressor.inflate(atob(loginData.preferences), { to: 'string' });
                var parsed = JSON.parse(result);
                this.sessionService.putPreference('inMemoryPreferences', parsed);
            }
            catch (ex) {
                this.loadPreferencesInMemory();
            }
        }
    };
    PreferencesService.prototype.loadPreferencesInMemory = function () {
        var inMemoryPreferences = this.sessionService.getPreference('inMemoryPreferences');
        if (inMemoryPreferences !== null) {
            for (var key in this.webStorageService.keys()) {
                if (this.preferenceMustBeLoadedInMemory(key)) {
                    inMemoryPreferences[key] = this.webStorageService.get(key);
                }
            }
        }
    };
    PreferencesService.prototype.preferenceMustBeLoadedInMemory = function (key) {
        var notInMemory = this.excluseMachinePreferences.filter(function (obj) {
            return obj === key;
        });
        return notInMemory.length === 0 ? true : false;
    };
    // TODO: Review this conversion
    PreferencesService.prototype.convertPreferencesToAngular2 = function () {
        var _this = this;
        Object.keys(localStorage)
            .forEach(function (preference) {
            if (preference.indexOf('Modulab.') > -1) {
                var preferenceName = preference.substring('Modulab.'.length);
                _this.putPreference(preferenceName, JSON.parse(localStorage.getItem(preference)));
            }
        });
    };
    return PreferencesService;
}());
PreferencesService.decorators = [
    { type: core_1.Injectable },
];
/** @nocollapse */
PreferencesService.ctorParameters = function () { return [
    { type: web_storage_1.WebStorageService, },
    { type: session_service_1.SessionService, },
]; };
exports.PreferencesService = PreferencesService;
//# sourceMappingURL=preferences.service.js.map